summaryrefslogtreecommitdiff
path: root/src/com/p4square/grow/frontend/TrainingPageResource.java
diff options
context:
space:
mode:
authorJesse Morgan <jesse@jesterpm.net>2013-09-15 16:57:53 -0700
committerJesse Morgan <jesse@jesterpm.net>2013-09-15 16:57:53 -0700
commit48af9ac4779b2d60889b0159f47442b5d6d9c8ce (patch)
treec51a021f4da706dede8c5360c8916da812c63e1e /src/com/p4square/grow/frontend/TrainingPageResource.java
parentc68f0faf73b92993875d8e7365427a54ff84fbaa (diff)
Adding Introduction Chapter.
Introduction chapter is always required and thus after the assessment the user is taken directly to the introduction. After the introduction training continues with whichever section the user assessed in to.
Diffstat (limited to 'src/com/p4square/grow/frontend/TrainingPageResource.java')
-rw-r--r--src/com/p4square/grow/frontend/TrainingPageResource.java8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/com/p4square/grow/frontend/TrainingPageResource.java b/src/com/p4square/grow/frontend/TrainingPageResource.java
index af49bc0..b27d86e 100644
--- a/src/com/p4square/grow/frontend/TrainingPageResource.java
+++ b/src/com/p4square/grow/frontend/TrainingPageResource.java
@@ -96,8 +96,8 @@ public class TrainingPageResource extends FreeMarkerPageResource {
}
if (mChapter == null) {
- // Everything is completed... send them back to seeker.
- mChapter = "seeker";
+ // Everything is completed... send them back to introduction.
+ mChapter = "introduction";
}
String nextPage = mConfig.getString("dynamicRoot", "");
@@ -185,8 +185,10 @@ public class TrainingPageResource extends FreeMarkerPageResource {
return 3;
} else if ("believer".equals(chapter)) {
return 2;
- } else {
+ } else if ("seeker".equals(chapter)) {
return 1;
+ } else {
+ return 0;
}
}
}